import Test.Cabal.Prelude

-- No description.
main = cabalTest $
  cabal "check" []
